@@ -1,12 +1,6 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
 import os
-from typing import Any, Dict
 
-def get_path_join(event: Dict[str, Any]) -> str:
+def get_path_join(event):
     """
     Takes an event with path parts in a list, turns them into
     an actual path, normalizes it, and sends it back.
