@@ -199,6 +199,7 @@ def log(log_event, params=None, check_mitosheet_install=False):
         for key, value in params.items():
             # We take any of the items that contain private user data, and we anonymize them
             if ('column_header' in key \
+                or 'column_id' in key \
                 or 'df_name' in key \
                 or 'dataframe_name' in key \
                 or 'analysis_name' in key \
@@ -211,7 +212,7 @@ def log(log_event, params=None, check_mitosheet_install=False):
             elif 'file_names' in key:
                 # Just count the number of files, instead of keeping their names
                 private_params[key] = len(value)
-            elif 'rows' in key or 'columns' in key or 'selected_columns' in key:
+            elif 'rows' in key or 'columns' in key or 'selected_column_ids' in key:
                 # We anonymize all of the column headers in any list
                 private_params[key] = [anonymize_word(v) for v in value]
             elif 'values' in key:
@@ -230,12 +231,15 @@ def log(log_event, params=None, check_mitosheet_install=False):
                         filter_log.append({'condition': filter_or_group['condition'],'value': len(str(filter_or_group['value']))})
 
                 private_params[key] = filter_log
+            elif 'old_value' in key:
+                private_params[key] = anonymize_word(value)
+            elif 'new_value' in key:
+                private_params[key] = anonymize_word(value)
             elif 'import_summaries' in key:
                 if value is not None:
                     private_params[key] = len(value)
                 else:
                     private_params[key] = value
-
             else:
                 private_params[key] = value
     except:
@@ -328,6 +332,15 @@ def log_event_processed(event, steps_manager, failed=False, edit_error=None):
             event_properties = {
                 'params_' + key: value for key, value in event['params'].items()
             }
+
+            # Try to log execution data for this step as well 
+            try:
+                execution_data_properties = {
+                    'execution_data_' + key: value for key, value in steps_manager.curr_step.execution_data.items()
+                }
+                event_properties = {**event_properties, **execution_data_properties}
+            except:
+                pass
         else:
             # Otherwise, we get the params from the highest level of the event 
             event_properties = {
