@@ -17,7 +17,7 @@ from ipywidgets import DOMWidget
 import traitlets as t
 
 from mitosheet._frontend import module_name, module_version
-from mitosheet.errors import EditError, get_recent_traceback_as_list
+from mitosheet.errors import EditError, get_recent_traceback, get_recent_traceback_as_list
 from mitosheet.saved_analyses import (
     read_and_upgrade_analysis, 
     write_analysis,
@@ -51,6 +51,7 @@ class MitoWidget(DOMWidget):
     df_sources_json = t.Unicode('').tag(sync=True)
     df_shape_json = t.Unicode('').tag(sync=True)
     saved_analysis_names_json = t.Unicode('').tag(sync=True)
+    column_ids_array_json = t.Unicode('').tag(sync=True)
     column_spreadsheet_code_json = t.Unicode('').tag(sync=True)
     column_filters_json = t.Unicode('').tag(sync=True)
     column_type_json = t.Unicode('').tag(sync=True)
@@ -63,7 +64,7 @@ class MitoWidget(DOMWidget):
     num_feedbacks = t.Int(0).tag(sync=True)
     num_usages = t.Int(0).tag(sync=True)
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args):
         """
         Takes a list of dataframes and strings that are paths to CSV files
         passed through *args.
@@ -108,6 +109,7 @@ class MitoWidget(DOMWidget):
         """
         self.sheet_json = self.steps_manager.sheet_json
         self.curr_step_idx = self.steps_manager.curr_step_idx
+        self.column_ids_array_json = self.steps_manager.column_ids_array_json
         self.column_spreadsheet_code_json = self.steps_manager.column_spreadsheet_code_json
         self.code_json = self.steps_manager.code_json
         self.df_names_json = self.steps_manager.df_names_json
@@ -213,7 +215,7 @@ class MitoWidget(DOMWidget):
             # api calls, as they are just noise.
             log_event_processed(event, self.steps_manager)
         except EditError as e:
-            print(get_recent_traceback_as_list())
+            print(get_recent_traceback())
             print(e)
             
             # Log processing this event failed
@@ -228,7 +230,7 @@ class MitoWidget(DOMWidget):
                 'to_fix': e.to_fix
             })
         except:
-            print(get_recent_traceback_as_list())
+            print(get_recent_traceback())
             # We log that processing failed, but have no edit error
             log_event_processed(event, self.steps_manager, failed=True)
             # Report it to the user, and then return
@@ -242,7 +244,6 @@ class MitoWidget(DOMWidget):
 
 def sheet(
         *args, 
-        saved_analysis_name=None
     ) -> MitoWidget:
     """
     Renders a Mito sheet. If no arguments are passed, renders an empty sheet. Otherwise, renders
@@ -252,7 +253,8 @@ def sheet(
     If running this function just prints text that looks like `MitoWidget(...`, then you need to 
     install the JupyterLab extension manager by running:
 
-    jupyter labextension install @jupyter-widgets/jupyterlab-manager@2;
+    python -m pip install mitoinstaller
+    python -m mitoinstaller install
 
     Run this command in the terminal where you installed Mito. It should take 5-10 minutes to complete.
 
@@ -262,14 +264,6 @@ def sheet(
     """
     args = list(args)
 
-    # We error if the saved analysis does not exist
-    if saved_analysis_name is not None and read_and_upgrade_analysis(saved_analysis_name) is None:
-        log(
-            'mitosheet_sheet_call_failed', 
-            {'error': f'There is no saved analysis with the name {saved_analysis_name}.'}
-        )
-        raise ValueError(f'There is no saved analysis with the name {saved_analysis_name}.')
-
     try:
         # We pass in the dataframes directly to the widget
         widget = MitoWidget(*args) 
@@ -287,9 +281,6 @@ def sheet(
     log(
         'mitosheet_sheet_call',
         dict(
-            **{
-                'param_saved_analysis_name': saved_analysis_name
-            },
             **{
                 # NOTE: analysis name is the UUID that mito saves the analysis under
                 'steps_manager_analysis_name': widget.steps_manager.analysis_name,
@@ -302,16 +293,5 @@ def sheet(
             }
         )
     )
-    
-    # If an analysis is passed, we pass this to the widget
-    if saved_analysis_name is not None:
-        widget.receive_message(widget, {
-            'event': 'update_event',
-            'id': get_new_id(),
-            'type': 'replay_analysis_update',
-            'analysis_name': saved_analysis_name,
-            'import_summaries': None,
-            'clear_existing_analysis': False
-        })
 
     return widget
